==> xwidgetsbase-1.5.3.tar.gz: lib/XfXWidgets/XfxElenco.dart <==
part of xwidgetbase;

class XfxElenco extends StatefulWidget {
  XfxElenco({
    Key? key,
    this.titleElenco = "",
    this.visibleXContainerWithLabelOnTop = true,
    this.headerVisible,
    this.filtersVisible = true,
    this.heightForHeader,
    this.listOfHeader,
    this.listOfFilters,
    this.numberOfHeader,
    this.list,
    this.flexForList,
    this.colorBackgroundContainerElTitle,
    this.heightContainerElTitle,
    this.styleElTitle,
    this.labelBTNOfTitle,
    this.colorBTNOfTitle,
    this.onPressedBTNOfTitle,
    this.heightBTNOfTitle,
    this.widthBTNOfTitle,
    this.visibleBTNofTitle = false,
    this.typeUIBTNofTitle,
    this.marginBTNofTitle,
  }) : super(key: key);
  final String titleElenco;
  final bool visibleXContainerWithLabelOnTop;
  final bool? headerVisible;
  final bool? filtersVisible;
  final double? heightForHeader;
  final List<Widget>? list;
  final List<Widget>? listOfHeader;
  final List<Widget>? listOfFilters;
  final int? numberOfHeader;
  final int? flexForList;
  final Color? colorBackgroundContainerElTitle;
  final double? heightContainerElTitle;
  final TextStyle? styleElTitle;
  final String? labelBTNOfTitle;
  final Color? colorBTNOfTitle;
  final Function()? onPressedBTNOfTitle;
  final double? heightBTNOfTitle;
  final double? widthBTNOfTitle;
  final bool? visibleBTNofTitle;
  final int? typeUIBTNofTitle;
  final EdgeInsets? marginBTNofTitle;
  @override
  _XfxElencoState createState() => _XfxElencoState();
}

class _XfxElencoState extends State<XfxElenco> {
  @override
  Widget build(BuildContext context) {
    return Container(
        margin: EdgeInsets.symmetric(horizontal: 15),
        child: Column(children: [
          SizedBox(height: 10),
          widget.visibleXContainerWithLabelOnTop == true
              ? Row(
                  children: [
                    Expanded(
                        child:
                            XContainerWithLabel(widget.titleElenco, height: widget.heightContainerElTitle ?? 30, color: widget.colorBackgroundContainerElTitle ?? xcolor_BackGroundTitleContainerForElenco, textStyle: widget.styleElTitle ?? XStyles.xStyTextForTextBase(XColors.xcolor_ForegroundDark))),
                    widget.visibleBTNofTitle == true
                        ? Container(
                            margin: widget.marginBTNofTitle ?? EdgeInsets.only(left: 5),
                            height: widget.heightBTNOfTitle ?? 25,
                            width: widget.widthBTNOfTitle ?? 70,
                            child: XBtnbase(
                              label: widget.labelBTNOfTitle ?? "Add New",
                              onPressed: widget.onPressedBTNOfTitle,
                              decorationBTN: BoxDecoration(color: widget.colorBTNOfTitle),
                            ),
                          )
                        : Container(),
                  ],
                )
              : Container(),
          SizedBox(height: widget.headerVisible == true ? 3 : 0),
          widget.headerVisible == true ? Row(children: widget.listOfHeader!) : Container(),
          SizedBox(height: widget.headerVisible == true ? 5 : 0),
          widget.filtersVisible == true ? Row(children: widget.listOfFilters!) : Container(),
          SizedBox(height: widget.filtersVisible == true ? 5 : 0),
          Expanded(
            flex: widget.flexForList ?? 18,
            child: ListView(children: widget.list!),
          ),
        ]));
  }
}

==> xwidgetsbase-8.7.7.tar.gz: lib/XfXWidgets/XfxElenco.dart <==
part of xwidgetbase;

class XfxElenco extends StatefulWidget {
  XfxElenco({
    Key? key,
    this.titleElenco = "",
    this.visibleXContainerWithLabelOnTop = true,
    this.headerVisible,
    this.filtersVisible = true,
    this.heightForHeader,
    this.listOfHeader,
    this.listOfFilters,
    this.numberOfHeader,
    this.list,
    this.flexForList,
    this.colorBackgroundContainerElTitle,
    this.heightContainerElTitle,
    this.styleElTitle,
    this.labelBTNOfTitle,
    this.colorBTNOfTitle,
    this.onPressedBTNOfTitle,
    this.heightBTNOfTitle,
    this.widthBTNOfTitle,
    this.visibleBTNofTitle = false,
    this.typeUIBTNofTitle,
    this.marginBTNofTitle,
    this.horizontalMarginOfElenco,
    required this.scrollController,
  }) : super(key: key);
  final ScrollController scrollController;
  final String titleElenco;
  final bool visibleXContainerWithLabelOnTop;
  final bool? headerVisible;
  final bool? filtersVisible;
  final double? heightForHeader;
  final List<Widget>? list;
  final List<Widget>? listOfHeader;
  final List<Widget>? listOfFilters;
  final int? numberOfHeader;
  final int? flexForList;
  final Color? colorBackgroundContainerElTitle;
  final double? heightContainerElTitle;
  final TextStyle? styleElTitle;
  final String? labelBTNOfTitle;
  final Color? colorBTNOfTitle;
  final Function()? onPressedBTNOfTitle;
  final double? heightBTNOfTitle;
  final double? widthBTNOfTitle;
  final bool? visibleBTNofTitle;
  final int? typeUIBTNofTitle;
  final EdgeInsets? marginBTNofTitle;
  final double? horizontalMarginOfElenco;
  @override
  _XfxElencoState createState() => _XfxElencoState();
}

class _XfxElencoState extends State<XfxElenco> {
  @override
  Widget build(BuildContext context) {
    return Container(
        margin: EdgeInsets.symmetric(horizontal: widget.horizontalMarginOfElenco ?? 15),
        child: Column(children: [
          widget.visibleXContainerWithLabelOnTop == true
              ? Row(
                  children: [
                    Expanded(
                        child:
                            XContainerWithLabel(widget.titleElenco, height: widget.heightContainerElTitle ?? 30, color: widget.colorBackgroundContainerElTitle ?? xcolor_BackGroundTitleContainerForElenco, textStyle: widget.styleElTitle ?? XStyles.xStyTextForTextBase(XColors.xcolor_ForegroundDark))),
                    widget.visibleBTNofTitle == true
                        ? Container(
                            margin: widget.marginBTNofTitle ?? EdgeInsets.only(left: 5),
                            height: widget.heightBTNOfTitle ?? 25,
                            width: widget.widthBTNOfTitle ?? 70,
                            child: XBtnbase(
                              label: widget.labelBTNOfTitle ?? "Add New",
                              onPressed: widget.onPressedBTNOfTitle,
                              decorationBTN: BoxDecoration(color: widget.colorBTNOfTitle),
                            ),
                          )
                        : Container(),
                  ],
                )
              : Container(),
          SizedBox(height: widget.headerVisible == true ? 3 : 0),
          widget.headerVisible == true ? Row(children: widget.listOfHeader!) : Container(),
          SizedBox(height: widget.headerVisible == true ? 5 : 0),
          widget.filtersVisible == true ? Row(children: widget.listOfFilters!) : Container(),
          SizedBox(height: widget.filtersVisible == true ? 5 : 0),
          Expanded(
              flex: widget.flexForList ?? 18,
              child: Scrollbar(
                  isAlwaysShown: true,
                  controller: widget.scrollController,
                  child: ListView(
                    children: widget.list!,
                    controller: widget.scrollController,
                  )))
        ]));
  }
}
